summaryrefslogtreecommitdiff
path: root/src/tile_cmd.h
diff options
context:
space:
mode:
authorsmatz <smatz@openttd.org>2009-09-20 17:44:33 +0000
committersmatz <smatz@openttd.org>2009-09-20 17:44:33 +0000
commit9225b3ba0315bf16322e15b4d71c3b2efc6d93a8 (patch)
tree0a35e6988310f33c2b662389f8cb65176222ceb7 /src/tile_cmd.h
parent2049d60e3460904e167fdd3e653b5e70fa4f0c9f (diff)
downloadopenttd-9225b3ba0315bf16322e15b4d71c3b2efc6d93a8.tar.xz
(svn r17589) -Codechange: rename town_acc to always_accepted
Diffstat (limited to 'src/tile_cmd.h')
-rw-r--r--src/tile_cmd.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/tile_cmd.h b/src/tile_cmd.h
index 593c0500f..748db79e8 100644
--- a/src/tile_cmd.h
+++ b/src/tile_cmd.h
@@ -78,11 +78,11 @@ typedef CommandCost ClearTileProc(TileIndex tile, DoCommandFlag flags);
/**
* Tile callback function signature for obtaining cargo acceptance of a tile
* @param tile Tile queried for its accepted cargo
* @param acceptance Storage destination of the cargo acceptance in 1/8
* @param town_acc Bitmask of town and headquarters-accepted cargo
*/
-typedef void AddAcceptedCargoProc(TileIndex tile, CargoArray &acceptance, uint32 *town_acc);
+typedef void AddAcceptedCargoProc(TileIndex tile, CargoArray &acceptance, uint32 *always_accepted);
/**
* Tile callback function signature for obtaining a tile description
@@ -165,12 +165,12 @@ VehicleEnterTileStatus VehicleEnterTile(Vehicle *v, TileIndex tile, int x, int y
void ChangeTileOwner(TileIndex tile, Owner old_owner, Owner new_owner);
void GetTileDesc(TileIndex tile, TileDesc *td);
-static inline void AddAcceptedCargo(TileIndex tile, CargoArray &acceptance, uint32 *town_acc)
+static inline void AddAcceptedCargo(TileIndex tile, CargoArray &acceptance, uint32 *always_accepted)
{
AddAcceptedCargoProc *proc = _tile_type_procs[GetTileType(tile)]->add_accepted_cargo_proc;
if (proc == NULL) return;
- uint32 dummy = 0; // use dummy bitmask so there don't need to be several 'town_acc != NULL' checks
- proc(tile, acceptance, town_acc == NULL ? &dummy : town_acc);
+ uint32 dummy = 0; // use dummy bitmask so there don't need to be several 'always_accepted != NULL' checks
+ proc(tile, acceptance, always_accepted == NULL ? &dummy : always_accepted);
}
static inline void AddProducedCargo(TileIndex tile, CargoArray &produced)
@@ -78,11 +78,11 @@ typedef CommandCost ClearTileProc(TileIndex tile, DoCommandFlag flags);
/**
* Tile callback function signature for obtaining cargo acceptance of a tile
- * @param tile Tile queried for its accepted cargo
- * @param acceptance Storage destination of the cargo acceptance in 1/8
- * @param town_acc Bitmask of town and headquarters-accepted cargo
+ * @param tile Tile queried for its accepted cargo
+ * @param acceptance Storage destination of the cargo acceptance in 1/8
+ * @param always_accepted Bitmask of town and headquarters-accepted cargo
*/